@@ -1,8 +1,8 @@
 #ifndef BONUSDISCIPLINEWINDOW_H
 #define BONUSDISCIPLINEWINDOW_H
 
-#include <QDialog>
 #include <QCheckBox>
+#include <QPushButton>
 #include "core/player.h"
 #include "controls/dialogwindow.h"
 #include "randomnumberpicker.h"
