@@ -283,6 +283,7 @@ void BookWindow::ShowSection(int section)
         QScriptValue objectValue = m_Engine.newQObject(m_Section);
         m_Engine.globalObject().setProperty("Section", objectValue);
 
+        // Autosave:
         if (newSection){
             bool saved = false;
 
@@ -748,6 +749,7 @@ void BookWindow::EndSlot()
             break;
         case EndWindow::Load:
             Init();
+            ShowSection(m_Section != NULL ? m_Section->Number : 0);
             break;
         case EndWindow::Restart:{
                 Load(GetBookSaveFilename(m_Book->Number));
@@ -1085,53 +1087,43 @@ bool BookWindow::Load(QString filename)
     if (m_Book->GetSerie() == Book::Magnakai){
         if(!m_Player->HasDiscipline("Camouflage")){
             Camouflage* d = new Camouflage(m_Player);
-            d->Serie = 0; // To avoid counting it in GetDisciplineCount
             m_Player->KaiDisciplines.append(d);
         }
         if(!m_Player->HasDiscipline("Hunting")){
             Hunting* d = new Hunting(m_Player);
-            d->Serie = 0; // To avoid counting it in GetDisciplineCount
             m_Player->KaiDisciplines.append(d);
         }
         if(!m_Player->HasDiscipline("Sixth Sense")){
             SixthSense* d = new SixthSense(m_Player);
-            d->Serie = 0; // To avoid counting it in GetDisciplineCount
             m_Player->KaiDisciplines.append(d);
         }
         if(!m_Player->HasDiscipline("Tracking")){
             Tracking* d = new Tracking(m_Player);
-            d->Serie = 0; // To avoid counting it in GetDisciplineCount
             m_Player->KaiDisciplines.append(d);
         }
         if(!m_Player->HasDiscipline("Healing")){
             Healing* d = new Healing(m_Player);
-            d->Serie = 0; // To avoid counting it in GetDisciplineCount
             m_Player->KaiDisciplines.append(d);
         }
         if(!m_Player->HasDiscipline("Weaponskill")){
             Weaponskill* d = new Weaponskill(m_Player);
             d->Weapon = Weapon::Sword; // Default to sword
-            d->Serie = 0; // To avoid counting it in GetDisciplineCount
             m_Player->KaiDisciplines.append(d);
         }
         if(!m_Player->HasDiscipline("Mindshield")){
             Mindshield* d = new Mindshield(m_Player);
-            d->Serie = 0; // To avoid counting it in GetDisciplineCount
             m_Player->KaiDisciplines.append(d);
         }
         if(!m_Player->HasDiscipline("Mindblast")){
             Mindblast* d = new Mindblast(m_Player);
-            d->Serie = 0; // To avoid counting it in GetDisciplineCount
             m_Player->KaiDisciplines.append(d);
         }
         if(!m_Player->HasDiscipline("Animal Kinship")){
             AnimalKinship* d = new AnimalKinship(m_Player);
-            d->Serie = 0; // To avoid counting it in GetDisciplineCount
             m_Player->KaiDisciplines.append(d);
         }
         if(!m_Player->HasDiscipline("Mind Over Matter")){
             MindOverMatter* d = new MindOverMatter(m_Player);
-            d->Serie = 0; // To avoid counting it in GetDisciplineCount
             m_Player->KaiDisciplines.append(d);
         }
     }
@@ -1141,11 +1133,6 @@ bool BookWindow::Load(QString filename)
         m->Serie = 0; // To avoid counting it in GetDisciplineCount
         m->Active = false;
         m_Player->KaiDisciplines.append(m);
-    }else if (m_Player->HasDiscipline("Psi-surge") && m_Player->HasDiscipline("Mindblast")){
-        KaiDiscipline* d = m_Player->GetDiscipline("Mindblast");
-        d->Serie = 0;
-    }else if (!m_Player->HasDiscipline("Psi-surge") && m_Player->HasDiscipline("Mindblast")){
-        m_Player->RemoveDiscipline("Mindblast");
     }
 
     // Change Psi-surge when reached Archmaster (9 Disciplines)
@@ -1155,6 +1142,12 @@ bool BookWindow::Load(QString filename)
         d->HelpText = "+6 COMBAT SKILL points but -1 ENDURANCE points per round";
     }
 
+    // Reset the serie of disciplines from other series (to avoid counting it in GetDisciplineCount):
+    foreach (KaiDiscipline* d, m_Player->KaiDisciplines){
+        if (d->Serie != m_Book->GetSerie())
+            d->Serie = 0;
+    }
+
     m_Loaded = true;
     return true;
 }
@@ -1170,6 +1163,7 @@ QString BookWindow::ChooseMeal(QString title)
 {
     ChooseItemWindow* dlg = new ChooseItemWindow(this, m_Player, ChooseItemWindow::ChooseMeal);
     dlg->setWindowTitle(title);
+    dlg->SetMessage(title);
     dlg->exec();
     return dlg->SelectedItem() ? dlg->SelectedItem()->Name : "";
 }
@@ -1178,6 +1172,7 @@ QString BookWindow::ChooseWeapon(QString title)
 {
     ChooseItemWindow* dlg = new ChooseItemWindow(this, m_Player, ChooseItemWindow::ChooseWeapon);
     dlg->setWindowTitle(title);
+    dlg->SetMessage(title);
     dlg->exec();
     return dlg->SelectedItem() ? dlg->SelectedItem()->Name : "";
 }
@@ -1186,6 +1181,7 @@ QString BookWindow::ChooseItem(QString title)
 {
     ChooseItemWindow* dlg = new ChooseItemWindow(this, m_Player, ChooseItemWindow::ChooseItem);
     dlg->setWindowTitle(title);
+    dlg->SetMessage(title);
     dlg->exec();
     return dlg->SelectedItem() ? dlg->SelectedItem()->Name : "";
 }
@@ -1194,6 +1190,7 @@ QString BookWindow::ChooseItemExceptMeals(QString title)
 {
     ChooseItemWindow* dlg = new ChooseItemWindow(this, m_Player, ChooseItemWindow::ChooseItemExceptMeals);
     dlg->setWindowTitle(title);
+    dlg->SetMessage(title);
     dlg->exec();
     return dlg->SelectedItem() ? dlg->SelectedItem()->Name : "";
 }
@@ -1202,6 +1199,7 @@ QString BookWindow::ChooseSpecialItem(QString title)
 {
     ChooseItemWindow* dlg = new ChooseItemWindow(this, m_Player, ChooseItemWindow::ChooseSpecialItem);
     dlg->setWindowTitle(title);
+    dlg->SetMessage(title);
     dlg->exec();
     return dlg->SelectedItem() ? dlg->SelectedItem()->Name : "";
 }
