@@ -191,6 +191,10 @@ public slots:
     QList<int> Classes();
     /** Adds a weapon class */
     void AddClass(int iClass);
+    /** Returns true if this weapon has the given class*/
+    bool HasClass(QString value);
+    /** Returns true if this weapon has the given class*/
+    bool HasClass(int value);
     /** Returns the hands needed to equip this weapon */
     int GetHands();
 
