@@ -720,6 +720,15 @@ QStringList Player::GetWeapons()
     return res;
 }
 
+QStringList Player::GetAllWeapons()
+{
+    QStringList res;
+    foreach (Weapon* w, Weapons(true)){
+        res.append(w->Name);
+    }
+    return res;
+}
+
 Weapon* Player::GetEquippedWeapon()
 {
     foreach (Item* i, Items){
@@ -800,12 +809,12 @@ bool Player::HasWeaponOfClass(QString wClass)
 
 bool Player::CanUseBow()
 {
-    return HasWeaponOfClass("Bow") && GetArrows() > 0;
+    return GetHands() == 2 && HasWeaponOfClass("Bow") && GetArrows() > 0;
 }
 
 Weapon* Player::GetWeapon(QString name)
 {
-    foreach(Weapon* w, Weapons()){
+    foreach(Weapon* w, Weapons(true)){
         if (QString::compare(w->Name, name, Qt::CaseInsensitive) == 0)
             return w;
     }
